# -*- coding: utf-8 -*-
"""code part 1

Automatically generated by Colaboratory.

Original file is located at
    https://colab.research.google.com/drive/11OdwLlHasWhUOsP7zIr7XQnF_VsM6kz4
"""

class one:
  def checkEorO(self,x):
  	if x/2==0:
		print(x,"is a even number")
  	else:
    		print(x,"is a odd number")


# -*- coding: utf-8 -*-
"""code part 2

Automatically generated by Colaboratory.

Original file is located at
    https://colab.research.google.com/drive/1cJiukCJ65HnHiQY8l9wEoaV8KwqxPsJ4
"""

class two:
  def checkP(self,x):
  	if x > 1:
   	# check for factors
   	for i in range(2,x):
      	 if (x % i) == 0:
           print(x,"is not a prime number")
           break
   	else:
      	 print(x,"is a prime number")
  	else:
 	 print(x,"is not a prime number")